@@ -1,26 +1,27 @@
 #############################################################################
 # Pod/Usage.pm -- print usage messages for the running script.
 #
-# Copyright (C) 1996-2000 by Bradford Appleton. All rights reserved.
-# This file is part of "PodParser". PodParser is free software;
+# Copyright (c) 1996-2000 by Bradford Appleton. All rights reserved.
+# Copyright (c) 2001-2016 by Marek Rouchal.
+# This file is part of "Pod-Usage". Pod-Usage is free software;
 # you can redistribute it and/or modify it under the same terms
 # as Perl itself.
 #############################################################################
 
 package Pod::Usage;
-use strict;
 
-use vars qw($VERSION @ISA @EXPORT);
-$VERSION = '1.65';  ## Current version of this package
+use strict;
 require  5.006;    ## requires this Perl version or later
 
-#use diagnostics;
 use Carp;
 use Config;
 use Exporter;
 use File::Spec;
 
-@EXPORT = qw(&pod2usage);
+our $VERSION = '2.00';  ## Current version of this package
+
+our @EXPORT = qw(&pod2usage);
+our @ISA;
 BEGIN {
     $Pod::Usage::Formatter ||= 'Pod::Text';
     eval "require $Pod::Usage::Formatter";
@@ -102,13 +103,13 @@ sub pod2usage {
 
         my @paths = (ref $pathspec) ? @$pathspec : split($pathsep, $pathspec);
         for my $dirname (@paths) {
-            $_ = File::Spec->catfile($dirname, $basename)  if length;
+            $_ = length($dirname) ? File::Spec->catfile($dirname, $basename) : $basename;
             last if (-e $_) && ($opts{'-input'} = $_);
         }
     }
 
     ## Now create a pod reader and constrain it to the desired sections.
-    my $parser = new Pod::Usage(USAGE_OPTIONS => \%opts);
+    my $parser = Pod::Usage->new(USAGE_OPTIONS => \%opts);
     if ($opts{'-verbose'} == 0) {
         $parser->select('(?:SYNOPSIS|USAGE)\s*');
     }
@@ -128,8 +129,9 @@ sub pod2usage {
     }
 
     ## Check for perldoc
-    my $progpath = File::Spec->catfile($Config{scriptdirexp} 
-	|| $Config{scriptdir}, 'perldoc');
+    my $progpath = $opts{'-perldoc'} ? $opts{'-perldoc'} :
+        File::Spec->catfile($Config{scriptdirexp} || $Config{scriptdir},
+            'perldoc');
 
     my $version = sprintf("%vd",$^V);
     if ($Config{versiononly} and $Config{startperl} =~ /\Q$version\E$/ ) {
@@ -148,10 +150,26 @@ sub pod2usage {
        if(defined $opts{-input} && $opts{-input} =~ /^\s*(\S.*?)\s*$/) {
          # the perldocs back to 5.005 should all have -F
 	 # without -F there are warnings in -T scripts
-         system($progpath, '-F', $1);
+	 my $f = $1;
+         my @perldoc_cmd = ($progpath);
+	 if ($opts{'-perldocopt'}) {
+           $opts{'-perldocopt'} =~ s/^\s+|\s+$//g;
+	   push @perldoc_cmd, split(/\s+/, $opts{'-perldocopt'});
+	 }
+	 push @perldoc_cmd, ('-F', $f);
+         unshift @perldoc_cmd, $opts{'-perlcmd'} if $opts{'-perlcmd'};
+         system(@perldoc_cmd);
+         # RT16091: fall back to more if perldoc failed
          if($?) {
-           # RT16091: fall back to more if perldoc failed
-           system(($Config{pager} || $ENV{PAGER} || '/bin/more'), $1);
+           # RT131844: prefer PAGER env
+           my $pager = $ENV{PAGER} || $Config{pager};
+           if(defined($pager) && length($pager)) {
+             my $cmd = $pager . ' ' . ($^O =~ /win/i ? qq("$f") : quotemeta($f));
+             system($cmd);
+           } else {
+             # the most humble fallback; should work (at least) on *nix and Win
+             system('more', $f);
+           }
          }
        } else {
          croak "Unspecified input file or insecure argument.\n";
@@ -265,7 +283,12 @@ sub select {
 sub seq_i { return $_[1] }
 # Override Pod::Text->cmd_i to return just "arg", not "*arg*".
 # newer version based on Pod::Simple
-sub cmd_i { return $_[2] }
+sub cmd_i {
+ my $self = shift;
+ # RT121489: highlighting should be there with Termcap
+ return $self->SUPER::cmd_i(@_) if $self->isa('Pod::Text::Termcap');
+ return $_[1];
+}
 
 # This overrides the Pod::Text method to do something very akin to what
 # Pod::Select did as well as the work done below by preprocess_paragraph.
@@ -317,7 +340,7 @@ sub _handle_element_end {
             $$self{PENDING}[-1][1] = $_;
         }
     }
-    if ($$self{USAGE_SKIPPING} && $element !~ m/^over-|^[BCFI]$/) {
+    if ($$self{USAGE_SKIPPING} && $element !~ m/^over-|^[BCFILSZ]$/) {
         pop @{ $$self{PENDING} };
     } else {
         $self->SUPER::_handle_element_end($element);
@@ -363,13 +386,15 @@ sub preprocess_paragraph {
 
 __END__
 
+=for stopwords pod2usage verboseness downcased MSWin32 Marek Rouchal Christiansen ATOOMIC rjbs McDougall
+
 =head1 NAME
 
-Pod::Usage - print a usage message from embedded pod documentation
+Pod::Usage - extracts POD documentation and shows usage information
 
 =head1 SYNOPSIS
 
-  use Pod::Usage
+  use Pod::Usage;
 
   my $message_text  = "This text precedes the usage message.";
   my $exit_status   = 2;          ## The exit status to use
@@ -381,17 +406,22 @@ Pod::Usage - print a usage message from embedded pod documentation
   pod2usage($exit_status);
 
   pod2usage( { -message => $message_text ,
-               -exitval => $exit_status  ,  
-               -verbose => $verbose_level,  
+               -exitval => $exit_status  ,
+               -verbose => $verbose_level,
                -output  => $filehandle } );
 
   pod2usage(   -msg     => $message_text ,
-               -exitval => $exit_status  ,  
-               -verbose => $verbose_level,  
-               -output  => $filehandle   );
+               -exitval => $exit_status  ,
+               -verbose => $verbose_level,
+               -output  => $filehandle );
 
   pod2usage(   -verbose => 2,
-               -noperldoc => 1  )
+               -noperldoc => 1  );
+
+  pod2usage(   -verbose => 2,
+               -perlcmd => $path_to_perl,
+               -perldoc => $path_to_perldoc,
+               -perldocopt => $perldoc_options );
 
 =head1 ARGUMENTS
 
@@ -423,49 +453,73 @@ keys:
 
 =over 4
 
-=item C<-message>
+=item C<-message> I<string>
 
-=item C<-msg>
+=item C<-msg> I<string>
 
 The text of a message to print immediately prior to printing the
-program's usage message. 
+program's usage message.
 
-=item C<-exitval>
+=item C<-exitval> I<value>
 
 The desired exit status to pass to the B<exit()> function.
-This should be an integer, or else the string "NOEXIT" to
+This should be an integer, or else the string C<NOEXIT> to
 indicate that control should simply be returned without
 terminating the invoking process.
 
-=item C<-verbose>
+=item C<-verbose> I<value>
 
-The desired level of "verboseness" to use when printing the usage
-message. If the corresponding value is 0, then only the "SYNOPSIS"
-section of the pod documentation is printed. If the corresponding value
-is 1, then the "SYNOPSIS" section, along with any section entitled
-"OPTIONS", "ARGUMENTS", or "OPTIONS AND ARGUMENTS" is printed.  If the
-corresponding value is 2 or more then the entire manpage is printed.
+The desired level of "verboseness" to use when printing the usage message.
+If the value is 0, then only the "SYNOPSIS" and/or "USAGE" sections of the
+pod documentation are printed. If the value is 1, then the "SYNOPSIS" and/or
+"USAGE" sections, along with any section entitled "OPTIONS", "ARGUMENTS", or
+"OPTIONS AND ARGUMENTS" is printed. If the corresponding value is 2 or more
+then the entire manpage is printed, using L<perldoc> if available; otherwise
+L<Pod::Text> is used for the formatting. For better readability, the
+all-capital headings are downcased, e.g. C<SYNOPSIS> =E<gt> C<Synopsis>.
 
 The special verbosity level 99 requires to also specify the -sections
 parameter; then these sections are extracted and printed.
 
-=item C<-sections>
+=item C<-sections> I<spec>
 
-A string representing a selection list for sections to be printed
-when -verbose is set to 99, e.g. C<"NAME|SYNOPSIS|DESCRIPTION|VERSION">.
+There are two ways to specify the selection. Either a string (scalar)
+representing a selection regexp for sections to be printed when -verbose
+is set to 99, e.g.
+
+  "NAME|SYNOPSIS|DESCRIPTION|VERSION"
+
+With the above regexp all content following (and including) any of the
+given C<=head1> headings will be shown. It is possible to restrict the
+output to particular subsections only, e.g.:
+
+  "DESCRIPTION/Algorithm"
+
+This will output only the C<=head2 Algorithm> heading and content within
+the C<=head1 DESCRIPTION> section. The regexp binding is stronger than the
+section separator, such that e.g.:
+
+  "DESCRIPTION|OPTIONS|ENVIRONMENT/Caveats"
+
+will print any C<=head2 Caveats> section (only) within any of the three
+C<=head1> sections.
 
 Alternatively, an array reference of section specifications can be used:
 
-  pod2usage(-verbose => 99, 
-            -sections => [ qw(fred fred/subsection) ] );
+  pod2usage(-verbose => 99, -sections => [
+    qw(DESCRIPTION DESCRIPTION/Introduction) ] );
 
-=item C<-output>
+This will print only the content of C<=head1 DESCRIPTION> and the
+C<=head2 Introduction> sections, but no other C<=head2>, and no other
+C<=head1> either.
+
+=item C<-output> I<handle>
 
 A reference to a filehandle, or the pathname of a file to which the
 usage message should be written. The default is C<\*STDERR> unless the
 exit value is less than 2 (in which case the default is C<\*STDOUT>).
 
-=item C<-input>
+=item C<-input> I<handle>
 
 A reference to a filehandle, or the pathname of a file from which the
 invoking script's pod documentation should be read.  It defaults to the
@@ -477,7 +531,7 @@ that module's POD, you can use this:
   use Pod::Find qw(pod_where);
   pod2usage( -input => pod_where({-inc => 1}, __PACKAGE__) );
 
-=item C<-pathlist>
+=item C<-pathlist> I<string>
 
 A list of directory paths. If the input file does not exist, then it
 will be searched for in the given directory list (in the order the
@@ -489,23 +543,48 @@ MSWin32 and DOS).
 
 =item C<-noperldoc>
 
+By default, Pod::Usage will call L<perldoc> when -verbose >= 2 is specified.
+This does not work well e.g. if the script was packed with L<PAR>. This option
+suppresses the external call to L<perldoc> and uses the simple text formatter
+(L<Pod::Text>) to output the POD.
+
+=item C<-perlcmd>
+
 By default, Pod::Usage will call L<perldoc> when -verbose >= 2 is
-specified. This does not work well e.g. if the script was packed
-with L<PAR>. The -noperldoc option suppresses the external call to
-L<perldoc> and uses the simple text formatter (L<Pod::Text>) to 
-output the POD.
+specified. In case of special or unusual Perl installations,
+this option may be used to supply the path to a L<perl> executable
+which should run L<perldoc>.
+
+=item C<-perldoc> I<path-to-perldoc>
+
+By default, Pod::Usage will call L<perldoc> when -verbose >= 2 is
+specified. In case L<perldoc> is not installed where the L<perl> interpreter
+thinks it is (see L<Config>), the -perldoc option may be used to supply
+the correct path to L<perldoc>.
+
+=item C<-perldocopt> I<string>
+
+By default, Pod::Usage will call L<perldoc> when -verbose >= 2 is specified.
+This option may be used to supply options to L<perldoc>. The
+string may contain several, space-separated options.
 
 =back
 
 =head2 Formatting base class
 
-The default text formatter is L<Pod::Text>.  The base class for Pod::Usage can
+The default text formatter is L<Pod::Text>. The base class for Pod::Usage can
 be defined by pre-setting C<$Pod::Usage::Formatter> I<before>
 loading Pod::Usage, e.g.:
 
     BEGIN { $Pod::Usage::Formatter = 'Pod::Text::Termcap'; }
     use Pod::Usage qw(pod2usage);
 
+Pod::Usage uses L<Pod::Simple>'s _handle_element_end() method to implement
+the section selection, and in case of verbosity < 2 it down-cases the
+all-caps headings to first capital letter and rest lowercase, and adds
+a colon/newline at the end of the headings, for better readability. Same for
+verbosity = 99.
+
 =head2 Pass-through options
 
 The following options are passed through to the underlying text formatter.
@@ -594,7 +673,7 @@ more verbose description of program usage in this case.
 
 =back
 
-B<pod2usage> doesn't force the above conventions upon you, but it will
+B<pod2usage> does not force the above conventions upon you, but it will
 use them by default if you don't expressly tell it to do otherwise.  The
 ability of B<pod2usage()> to accept a single number or a string makes it
 convenient to use as an innocent looking error message handling function:
@@ -783,7 +862,7 @@ things:
 
 By default, B<pod2usage()> will use C<$0> as the path to the pod input
 file.  Unfortunately, not all systems on which Perl runs will set C<$0>
-properly (although if C<$0> isn't found, B<pod2usage()> will search
+properly (although if C<$0> is not found, B<pod2usage()> will search
 C<$ENV{PATH}> or else the list specified by the C<-pathlist> option).
 If this is the case for your system, you may need to explicitly specify
 the path to the pod docs for the invoking script using something
@@ -800,23 +879,45 @@ the script:
     use FindBin;
     pod2usage(-input => $FindBin::Bin . "/" . $FindBin::Script);
 
+=head1 SUPPORT
+
+This module is managed in a GitHub repository,
+L<https://github.com/Dual-Life/Pod-Usage> Feel free to fork and contribute, or
+to clone and send patches!
+
+Please use L<https://github.com/Dual-Life/Pod-Usage/issues/new> to file a bug
+report.  The previous ticketing system,
+L<https://rt.cpan.org/Dist/Display.html?Queue=Pod-Usage>, is deprecated for
+this package.
+
+More general questions or discussion about POD should be sent to the
+C<pod-people@perl.org> mail list. Send an empty email to
+C<pod-people-subscribe@perl.org> to subscribe.
+
 =head1 AUTHOR
 
-Please report bugs using L<http://rt.cpan.org>.
-
 Marek Rouchal E<lt>marekr@cpan.orgE<gt>
 
+Nicolas R E<lt>nicolas@atoomic.orgE<gt>
+
 Brad Appleton E<lt>bradapp@enteract.comE<gt>
 
 Based on code for B<Pod::Text::pod2text()> written by
 Tom Christiansen E<lt>tchrist@mox.perl.comE<gt>
 
+=head1 LICENSE
+
+Pod::Usage (the distribution) is licensed under the same terms as Perl.
+
 =head1 ACKNOWLEDGMENTS
 
+Nicolas R (ATOOMIC) for setting up the Github repo and modernizing this
+package.
+
 rjbs for refactoring Pod::Usage to not use Pod::Parser any more.
 
-Steven McDougall E<lt>swmcd@world.std.comE<gt> for his help and patience
-with re-writing this manpage.
+Steven McDougall E<lt>swmcd@world.std.comE<gt> for his help and patience with
+re-writing this manpage.
 
 =head1 SEE ALSO
 
